<?php
/*
Plugin Name: Page Lists Plus
Plugin URI: http://www.technokinetics.com/plugins/page-lists-plus/
Description: Adds customisation options to the wp_list_pages function which is used to create Page menus. Change the link text and title attributes, redirect, nofollow or unlink links, and remove links from page lists altogether, all through the WordPress dashboard.
Version: 0.1.1
Author: Tim Holt
Author URI: http://www.technokinetics.com/

    Copyright 2008 Tim Holt (tim@technokinetics.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

// HOOKS

register_activation_hook(__FILE__,'page_lists_plus_install');
register_deactivation_hook( __FILE__, 'page_lists_plus_uninstall' );
add_action('admin_menu', 'page_lists_plus_add_fields');
add_action('save_post', 'save_page_lists_plus');
add_filter('wp_list_pages_excludes', 'page_exclusions');
add_filter('wp_list_pages', 'page_lists_plus');
add_action('admin_menu', 'add_page_lists_plus_admin_menu');



// ACTIVATION

function page_lists_plus_install() {
	global $wpdb;
	$posts_table = $wpdb->prefix . 'posts';
	mysql_query("ALTER TABLE " . $posts_table . " ADD show_in_menu TINYINT(1) DEFAULT 1 NOT NULL AFTER post_title");
	mysql_query("ALTER TABLE " . $posts_table . " ADD link_link TINYINT(1) DEFAULT 1 NOT NULL AFTER show_in_menu");
	mysql_query("ALTER TABLE " . $posts_table . " ADD no_follow_link TINYINT(1) DEFAULT 0 NOT NULL AFTER link_link");
	mysql_query("ALTER TABLE " . $posts_table . " ADD alt_link_text VARCHAR(60) AFTER no_follow_link");
	mysql_query("ALTER TABLE " . $posts_table . " ADD redirect_url VARCHAR(100) AFTER alt_link_text");
	mysql_query("ALTER TABLE " . $posts_table . " ADD alt_title_attribute VARCHAR(100) AFTER redirect_url");
}



// DEACTIVATION

function page_lists_plus_uninstall() {
	global $wpdb;
	$posts_table = $wpdb->prefix . 'posts';
	// If the following lines are uncommented, deactivating the plugin will remove any trace of it
	// mysql_query("ALTER TABLE " . $posts_table . " DROP show_in_menu");
	// mysql_query("ALTER TABLE " . $posts_table . " DROP link_link");
	// mysql_query("ALTER TABLE " . $posts_table . " DROP no_follow_link");
	// mysql_query("ALTER TABLE " . $posts_table . " DROP alt_link_text");
	// mysql_query("ALTER TABLE " . $posts_table . " DROP redirect_url");
	// mysql_query("ALTER TABLE " . $posts_table . " DROP alt_title_attribute");
}



// ADMIN MENU
function add_page_lists_plus_admin_menu() {
	add_management_page('Page Lists Plus', 'Page Lists Plus', 9, __FILE__, 'page_lists_plus_admin_menu');
}

function page_lists_plus_admin_menu() { ?>
	<div id="page_lists_plus" class="wrap">
		<h2>Page Lists Plus</h2>
		<form method="post" action="options.php">
			<ul style="list-style: none;">
				<li><input type="checkbox" id="plp_label_first_item" name="plp_label_first_item" <?php if (get_option('plp_label_first_item') == "on") { echo 'checked="checked" '; } ?>/> <label for="plp_label_first_item">Add class="first_item" to first list item</label></li>
			</ul>
			<p>
				<?php wp_nonce_field('update-options'); ?>
				<input type="hidden" name="action" value="update" />
				<input type="hidden" name="page_options" value="plp_add_home_link,plp_label_first_item" />
			</p>
			<p class="submit"><input type="submit" name="Submit" value="<?php _e('Save Changes') ?>" /></p>
		</form>		
	</div><?php
}

// ADD FIELD

function page_lists_plus_add_fields() {
	if (function_exists('add_meta_box')) {
		add_meta_box('page_lists_plus_box', 'Page Lists Plus', 'page_lists_plus_inner', 'page', 'normal', 'low');
	}
}

function page_lists_plus_inner() {
	global $post, $show_in_menu, $alt_link_text, $alt_title_attribute; ?>
	<p><label for="show_in_menu">Include</label><br/><input type="checkbox" id="show_in_menu" name="show_in_menu" <?php if (!isset($post->show_in_menu) || $post->show_in_menu == 1) { echo 'checked="checked" '; } ?>/> If this box is checked, then this Page will appear in page lists generated using wp_list_pages().</p>
	<p><label for="link_link">Link</label><br/><input type="checkbox" id="link_link" name="link_link" <?php if (!isset($post->show_in_menu) || $post->link_link == 1) { echo 'checked="checked" '; } ?>/> If this box is checked, then this Page will be linked in lists generated using wp_list_pages().</p>
	<p><label for="no_follow_link">Nofollow</label><br/><input type="checkbox" id="no_follow_link" name="no_follow_link" <?php if ($post->no_follow_link == 1) { echo 'checked="checked" '; } ?>/> If this box is checked, then links to this Page in lists generated using wp_list_pages() will have rel="nofollow" added.</p>
	<p><label for="alt_link_text">Alternative Link Text</label><br/><input type="text" id="alt_link_text" name="alt_link_text" value="<?php echo $post->alt_link_text; ?>" /> This link text will be used in page lists generated using wp_list_pages().</p>
	<p><label for="alt_title_attribute">Alternative Title Attribute</label><br/><input type="text" id="alt_title_attribute" name="alt_title_attribute" value="<?php echo $post->alt_title_attribute; ?>" /> This title attribute will be used in page lists generated using wp_list_pages().</p>
	<p><label for="redirect_url">Redirect To</label><br/><input type="text" id="redirect_url" name="redirect_url" value="<?php echo $post->redirect_url; ?>" /> This url will be used in lists generated using wp_list_pages as this Page's link's destination.</p>
	<p><input type="hidden" name="manual_save" value="manual_save" /></p><?php
}

// SAVE ALT ANCHOR

function save_page_lists_plus() {

	global $wpdb;
	$posts_table = $wpdb->prefix . 'posts';
	
	if ($_POST[manual_save] == 'manual_save') {
	
		if ($_POST[show_in_menu]) {
			mysql_query("UPDATE " . $posts_table . " SET show_in_menu = '1' WHERE ID = $_POST[ID]");
		} else {
			mysql_query("UPDATE " . $posts_table . " SET show_in_menu = '0' WHERE ID = $_POST[ID]");
		}
	
		if ($_POST[link_link]) {
			mysql_query("UPDATE " . $posts_table . " SET link_link = '1' WHERE ID = $_POST[ID]");
		} else {
			mysql_query("UPDATE " . $posts_table . " SET link_link = '0' WHERE ID = $_POST[ID]");
		}
	
		if ($_POST[no_follow_link]) {
			mysql_query("UPDATE " . $posts_table . " SET no_follow_link = '1' WHERE ID = $_POST[ID]");
		} else {
			mysql_query("UPDATE " . $posts_table . " SET no_follow_link = '0' WHERE ID = $_POST[ID]");
		}
	
		if ($_POST[alt_link_text] == "") {
			mysql_query("UPDATE " . $posts_table . " SET alt_link_text = null WHERE ID = $_POST[ID]");
		} else {
			mysql_query("UPDATE " . $posts_table . " SET alt_link_text = '" . $_POST[alt_link_text] . "' WHERE ID = $_POST[ID]");
		}
	
		if ($_POST[redirect_url] == "") {
			mysql_query("UPDATE " . $posts_table . " SET redirect_url = null WHERE ID = $_POST[ID]");
		} else {
			mysql_query("UPDATE " . $posts_table . " SET redirect_url = '" . $_POST[redirect_url] . "' WHERE ID = $_POST[ID]");
		}
	
		if ($_POST[alt_title_attribute] == "") {
			mysql_query("UPDATE " . $posts_table . " SET alt_title_attribute = null WHERE ID = $_POST[ID]");
		} else {
			mysql_query("UPDATE " . $posts_table . " SET alt_title_attribute = '" . $_POST[alt_title_attribute] . "' WHERE ID = $_POST[ID]");
		}
	
	}
	
}



// EXCLUDE PAGES FROM PAGE LIST

function page_exclusions($page_exclusions) {
	global $wpdb;
	$posts_table = $wpdb->prefix . 'posts';
	$page_exlusions_data = mysql_query("SELECT ID FROM " . $posts_table . " WHERE show_in_menu = '0' AND post_status = 'publish'");
	while ($row = mysql_fetch_assoc($page_exlusions_data)) {
		extract($row);
		$page_exclusions[] = $ID;
	}
	return $page_exclusions;
}



// REPLACEMENTS IN WP-LIST-PAGES RESULTS

function page_lists_plus($output) {	
	global $wpdb;
	$posts_table = $wpdb->prefix . 'posts';
	
	$no_follow_link_data = mysql_query("SELECT post_title, no_follow_link FROM " . $posts_table . " WHERE no_follow_link = '1' AND post_status = 'publish'");
	while ($row = mysql_fetch_assoc($no_follow_link_data)) {
		extract($row);
		$post_title = wptexturize($post_title);
		$output = str_replace('>' . $post_title, ' rel="nofollow">' . $post_title, $output);
	}
	
	$alt_title_attribute_data = mysql_query("SELECT post_title, alt_title_attribute FROM " . $posts_table . " WHERE alt_title_attribute IS NOT NULL AND post_status = 'publish'");
	while ($row = mysql_fetch_assoc($alt_title_attribute_data)) {
		extract($row);
		$post_title = wptexturize($post_title);
		$output = str_replace('title="' . $post_title, 'title="' . $alt_title_attribute, $output);
	}
	
	$link_link_data = mysql_query("SELECT post_title FROM " . $posts_table . " WHERE link_link = '0' AND post_status = 'publish'");
	while ($row = mysql_fetch_assoc($link_link_data)) {
		extract($row);
		$post_title = wptexturize($post_title);
		$output = preg_replace('`<a(.+)' . $post_title . '(.+)+/a>`', $post_title, $output);
	}
	
	$alt_link_text_data = mysql_query("SELECT post_title, alt_link_text FROM " . $posts_table . " WHERE alt_link_text IS NOT NULL AND post_status = 'publish'");
	while ($row = mysql_fetch_assoc($alt_link_text_data)) {
		extract($row);
		$post_title = wptexturize($post_title);
		$output = str_replace('>' . $post_title, '>' . $alt_link_text, $output);
	}
	
	$redirect_url_data = mysql_query("SELECT ID, redirect_url FROM " . $posts_table . " WHERE redirect_url IS NOT NULL AND post_status = 'publish'");
	while ($row = mysql_fetch_assoc($redirect_url_data)) {
		extract($row);
		$page_url = get_permalink($ID);
		$output = str_replace($page_url, $redirect_url, $output);
	}
	
	if (get_option('plp_label_first_item') == 'on') {
		$output = preg_replace('`class="page_item`', 'class="first_item page_item', $output, 1);
	}
	
	return $output;
}

?>